@@ -1,5 +1,6 @@
 # parse 74
 # Sam Robson
+
 import os
 import sys
 import glob
@@ -582,9 +583,12 @@ def log_complete(conf, start_time, output=None):
     cases_per_sec = max_cases/elapsed
     if tablog:
         click.secho(output)
-    if launch:
+    if launch and not arc_out:
         time.sleep(5)
-        click.launch(path_out)
+        try:
+            click.launch(path_out)
+        except AttributeError:
+            click.echo("Failed to launch!")
     if tablog or print_log:
         click.clear()
         click.echo(f'''\nTASK COMPLETED: Successfully processed {max_cases} cases. Last batch completed in {elapsed:.2f} seconds ({cases_per_sec:.2f} cases/sec)''')
